CircularCarouselController class
- Inheritance
-
- Object
- ChangeNotifier
- CircularCarouselController
Constructors
- CircularCarouselController({int itemsLength = 0})
Properties
- animationCurve ↔ Curve?
-
getter/setter pair
- animationDuration ↔ Duration?
-
getter/setter pair
- currentPage ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- itemsLength ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
nextPage(
{Duration? duration, Curve? curve}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
override
-
previousPage(
{Duration? duration, Curve? curve}) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited